# Ceridian Dayforce Connector
> Cloud HCM software that brings together real-time payroll, HR, benefits, time reporting, talent and workforce management to deliver intelligence at work.

🔗 https://www.ceridian.com/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |